@@ -86,6 +86,7 @@ kcca.list <- function (x, k, family, control, fuzzy = FALSE, ...)
           converged <- TRUE
      }
 
+     distmat <- family@dist(x, centers, ...)
      cluster <- family@cluster(distmat = distmat, m = control@fuzziness)
 
      if (fuzzy) {
@@ -95,8 +96,6 @@ kcca.list <- function (x, k, family, control, fuzzy = FALSE, ...)
 
           cluster <- max.col(-distmat, "first")
 
-          centers <- consistency_check(centers, "tsmat")
-
      } else {
           fcluster <- matrix(NA_real_)
      }
