@@ -86,7 +86,7 @@ lb_keogh <- function(x, y, window.size = NULL, norm = "L1", lower.env = NULL, up
 
      ## NOTE: the 'window.size' definition varies betwen 'dtw' and 'runminmax'
      if (is.null(lower.env) && is.null(upper.env)) {
-          envelopes <- call_runminmax(y, window.size*2L + 1L)
+          envelopes <- call_envelop(y, window.size*2L + 1L)
           lower.env <- envelopes$min
           upper.env <- envelopes$max
 
@@ -153,7 +153,7 @@ lb_keogh_loop <- function(x, y = NULL, window.size = NULL, error.check = TRUE,
      }
 
      ## NOTE: the 'window.size' definition varies betwen 'dtw' and 'runminmax'
-     envelops <- lapply(y, function(s) { call_runminmax(s, window.size*2L + 1L) })
+     envelops <- lapply(y, function(s) { call_envelop(s, window.size*2L + 1L) })
 
      lower.env <- lapply(envelops, "[[", "min")
      upper.env <- lapply(envelops, "[[", "max")
